## 📆 tg_calendar

Универсальный интерактивный календарь для Telegram-ботов на `aiogram 3`.

Позволяет удобно отображать иконки событий на датах, выбирать день, месяц и год. Подходит для любых целей: тренировки, задачи, встречи, праздники и т.п.

🔹 **Протестировать** бота: [@test_telegram_calendar_bot](https://t.me/test_telegram_calendar_bot)
